#ifndef _IMAGES_H
#include <kstandarddirs.h>
#define _IMAGES_H

#define IMAGE_SPLASH 		locate("appdata", "pics/konquest-splash.gif")
#define IMAGE_PLANET_1		locate("appdata", "pics/planet1.xpm")
#define IMAGE_PLANET_2		locate("appdata", "pics/planet2.xpm")
#define IMAGE_PLANET_3		locate("appdata", "pics/planet3.xpm")
#define IMAGE_PLANET_4		locate("appdata", "pics/planet4.xpm")
#define IMAGE_PLANET_5		locate("appdata", "pics/planet5.xpm")
#define IMAGE_PLANET_6		locate("appdata", "pics/planet6.xpm")
#define IMAGE_PLANET_7		locate("appdata", "pics/planet7.xpm")
#define IMAGE_PLANET_8		locate("appdata", "pics/planet8.xpm")
#define IMAGE_PLANET_9		locate("appdata", "pics/planet9.xpm")

#endif // _IMAGES_H

